@@ -5,7 +5,7 @@ use Mojo::Collection;
 use Mojo::JSON 'from_json';
 use Mojo::Util 'tablify';
 
-has 'sth';
+has [qw(db sth)];
 
 sub DESTROY {
   my $self = shift;
@@ -86,6 +86,13 @@ L<Mojo::Pg::Database>.
 
 L<Mojo::Pg::Results> implements the following attributes.
 
+=head2 db
+
+  my $db   = $results->db;
+  $results = $results->db(Mojo::Pg::Database->new);
+
+L<Mojo::Pg::Database> object these results belong to.
+
 =head2 sth
 
   my $sth  = $results->sth;
@@ -190,6 +197,6 @@ L<Mojo::Util/"tablify">.
 
 =head1 SEE ALSO
 
-L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Mojo::Pg>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
